==> campsite-2.4.1.tar.gz: campsite/implementation/management/priv/lang/pt/articles.php <==
<?php
regGS("to section", "para secção");
regGS("You must select at least one article to perform an action.", "Tem de selecionar um artigo para efectuar operação");
regGS("You must choose a language", "Tem de escolher um idioma");
regGS("You may only translate one article at a time.", "Só pode traduzir um artigo de cada vez");
regGS("View article", "Ver artigos");
regGS("Unable to create the section for translation $1.", "Não é possivél criar a secção para traduzir $1.");
regGS("Unable to create the issue for translation $1.", "Não é possivél criar a edição para traduzir $1.");
regGS("The following articles are new; it is not possible to schedule them for automatic publishing", "Os artigos seguintes são novos; não é possivél agendar para publicação automática.");
regGS("Status: Submitted", "Estado : Submetido");
regGS("Status: Submit", "Estado : Submeter");
regGS("Status: Set New", "Estado : Novo");
regGS("Status: Published", "Estado : Publicado");
regGS("Status: Publish", "Estado : Publicar");
regGS("Status: New", "Estado : Novo");
regGS("Select None", "Limpar selecção");
regGS("Select All", "Selecionar todos");
regGS("Section URL Name", "Nome URL da secção");
regGS("Section Name", "Nome da secção");
regGS("Publish date", "Data de publicação");
regGS("Publish Schedule", "Agendamento de publicação");
regGS("On Section Page", "Na página de secção");
regGS("On Front Page", "Na página principal");
regGS("No action specified", "Sem acção especificada");
regGS("New section name", "Novo nome de secção");
regGS("New section URL name", "Novo nome de URL de secção");
regGS("New issue name", "Novo nome de edição");
regGS("New issue URL name", "Novo nome URL de edição");
regGS("New article name", "Novo nome de artigo");
regGS("Issue URL Name", "Nome URL da edição");
regGS("Issue Name", "Nome da edição");
regGS("Files", "Ficheiros");
regGS("Duplicate?", "Duplicar?");
regGS("Duplicate to another section", "Duplicar para outra secção");
regGS("Duplicate articles", "Duplicar artigos");
regGS("Creation date", "Data da criação");
regGS("Created by", "Criado por");
regGS("Article name ($1)", "Nome do Artigo ($1)");
regGS("Article List", "Lista de artigos");
regGS("Are you sure you want to remove the topic \'$1\' from the article?", "");
regGS("Are you sure you want to remove the file \'$1\' from the article?", "");
regGS("Are you sure you want to remove the event scheduled on $1?", "Confirma a eliminação do agendamento para $1?");
regGS("Are you sure you want to delete this article?", "Confirma a eliminação deste artigo?");
regGS("Are you sure you want to delete the selected articles?", "Confirma a eliminação do artigos selecionados?");
regGS("An issue must be created for the selected language.  Please enter the issue name and URL name.", "Tem de existir uma edição para o idioma selecionado. Introduza o nome da edição e respectivo nome URL.");
regGS("All", "Todos");
regGS("Add Event", "Adicionar evento");
regGS("A section must be created for the selected language.  Please enter the section name and URL name.", "Tem de existir uma secção para o idioma selecionado. Introduza o nome da secção e respectivo nome URL.");
regGS("Article Type", "Tipo de artigo");
regGS("$1 articles found", "exist(m) $1 artigo(s).");
regGS("Show article on front page", "Mostrar Artigo na 1ª Página");
regGS("Show article on section page", "Mostrar Artigo na página de Secção");
regGS("Translate article", "Traduzir Artigo");
regGS("You do not have the right to change this article.  You may only edit your own articles and once submitted an article can only be changed by authorized users.", "Não tem permissões para alterar o Estado do Artigo. Apenas pode alterar os seus artigos, mas após um artigo ser submetido apenas poderá ser alterado por Utilizadores autorizados pelo Sistema.");
regGS("Edit article", "Editar Detalhes do Artigo");
regGS("Allow users without subscriptions to view the article", "Permitir que leitores sem assinatura vejam Artigo.");
regGS("The article has been locked by $1 ($2) $3 hour(s) and $4 minute(s) ago.", "O artigo foi bloqueado por $1 ($2) à $3 horas e $4 minutos.");
regGS("The article has been locked by $1 ($2) $3 minute(s) ago.", "O artigo foi bloqueado por $1 ($2) à $3 minutos.");
regGS("Are you sure you want to unlock it?", "Confirme o desbloqueamento");
regGS("Article is locked", "Artigo bloqueado");
regGS("Duplicate article", "Duplicar Artigo");
regGS("The destination section is the same as the source section.", "Secção destino idêntica à de origem.");
regGS("The article is new; it is not possible to schedule it for automatic publishing.", "Este artigo é novo; não é possivél agendar publicação automática.");
regGS("No article types were defined. You must create an article type first.", "Não existem tipos de artigos definidos. Tem de criar tipo de artigo antes.");
regGS("Edit article types", "Editar tipos de artigos");
regGS("Could not save the article. It has been locked by $1 $2 hours and $3 minutes ago.", "Não é possivél gravar artigo. Este foi bloqueado por $1 à $2 horas e $3 minutos.");
regGS("You do not have the right to change this article status. Once submitted an article can only be changed by authorized users.", "Não tem permissões para alterar o estado do artigo. Uma vez submetido apenas os utilizadores autorizados podem alterar o seu estado.");
regGS("You do not have the right to delete articles.", "Não tem permissões para eliminar artigos. ");
regGS("You must select an article type.", "Tem de escolher o tipo de artigo.");
regGS("Are you sure you want to remove the image \'$1\' from the article?", "");
regGS("Are you sure you want to delete this scheduled action?", "");
regGS("Are you sure you want to remove the topic \\'$1\\' from the article?", "Confirma a eliminação do tópico \\'$1\\' do artigo?");
regGS("Are you sure you want to remove the file \\'$1\\' from the article?", "Confirma a eliminação do anexo \\'$1\\' do artigo?");
regGS("Are you sure you want to remove the image \\'$1\\' from the article?", "Confirma a eliminação da imagem \\'$1\\' do artigo?");
?>

==> campsite-2.5.1.tar.gz: campsite/implementation/management/priv/lang/pt/articles.php <==
<?php
regGS("The article has already been translated into $1.", "Este artigo ja foi traduzido para $1");
regGS("move", "mover");
regGS("duplicate", "duplicar");
regGS("You must set the publication, issue, and section for this article before you can schedule it for publishing.  Go to the \"$1\" menu and select \"$2\" to do this.", "Tem de escolher a publicação, numero e secção para este artigo antes de agendar a sua publicação. Vá ao menu $1 e escolha a opção $2 para fazê-lo");
regGS("You do not have the right to translate articles.", "Não tem permissão para traduzir artigos.");
regGS("You do not have the right to publish articles.", "Não tem permissão para publicar artigos");
regGS("You do not have the right to move articles.", "Não tem permissão para mover artigos.");
regGS("You cannot $1 the articles marked in red because the destination issue has not been translated into the appropriate language.", "Não pode mover os artigos assinalados a vermelho porque a edição de destino não se encontra traduzido para o idioma apropriado.");
regGS("Select location (optional):", "Selecione a localização ( opcional ):");
regGS("Publish?", "Publicar?");
regGS("Publish articles", "Publicar artigos");
regGS("Publish article", "Publicar artigo");
regGS("Move?", "Mover?");
regGS("Move articles", "Mover artigos");
regGS("Move article", "Mover artigo");
regGS("Move", "Mover");
regGS("An issue must be created for the selected language but you do not have the right to create an issue.", "Tem de criar uma edição para o idioma escolhido, mas não possui permissões para tal.");
regGS("A section must be created for the selected language but you do not have the right to create a section.", "Tem de criar um secção para o idioma escolhido, mas não possui permissões para tal.");
regGS("to section", "para secção");
regGS("You must select at least one article to perform an action.", "Tem de selecionar um artigo para efectuar operação");
regGS("You must choose a language", "Tem de escolher um idioma");
regGS("You may only translate one article at a time.", "Só pode traduzir um artigo de cada vez");
regGS("View article", "Ver artigos");
regGS("Unable to create the section for translation $1.", "Não é possivél criar a secção para traduzir $1.");
regGS("Unable to create the issue for translation $1.", "Não é possivél criar a edição para traduzir $1.");
regGS("The following articles are new; it is not possible to schedule them for automatic publishing", "Os artigos seguintes são novos; não é possivél agendar para publicação automática.");
regGS("Status: Submitted", "Estado : Submetido");
regGS("Status: Submit", "Estado : Submeter");
regGS("Status: Set New", "Estado : Novo");
regGS("Status: Published", "Estado : Publicado");
regGS("Status: Publish", "Estado : Publicar");
regGS("Status: New", "Estado : Novo");
regGS("Section URL Name", "Nome URL da secção");
regGS("Section Name", "Nome da secção");
regGS("Publish date", "Data de publicação");
regGS("Publish Schedule", "Agendamento de publicação");
regGS("No action specified", "Sem acção especificada");
regGS("New section name", "Novo nome de secção");
regGS("New section URL name", "Novo nome de URL de secção");
regGS("New issue name", "Novo nome de edição");
regGS("New issue URL name", "Novo nome URL de edição");
regGS("New article name", "Novo nome de artigo");
regGS("Issue URL Name", "Nome URL da edição");
regGS("Issue Name", "Nome da edição");
regGS("Files", "Ficheiros");
regGS("Duplicate?", "Duplicar?");
regGS("Duplicate to another section", "Duplicar para outra secção");
regGS("Duplicate articles", "Duplicar artigos");
regGS("Article name ($1)", "Nome do Artigo ($1)");
regGS("Article List", "Lista de artigos");
regGS("Are you sure you want to remove the topic \'$1\' from the article?", "Confirma a eliminação do tópico \'$1\' do artigo?");
regGS("Are you sure you want to remove the file \'$1\' from the article?", "Confirma a eliminação do anexo \'$1\' do artigo?");
regGS("Are you sure you want to remove the event scheduled on $1?", "Confirma a eliminação do agendamento para $1?");
regGS("Are you sure you want to delete this article?", "Confirma a eliminação deste artigo?");
regGS("Are you sure you want to delete the selected articles?", "Confirma a eliminação do artigos selecionados?");
regGS("An issue must be created for the selected language.  Please enter the issue name and URL name.", "Tem de existir uma edição para o idioma selecionado. Introduza o nome da edição e respectivo nome URL.");
regGS("All", "Todos");
regGS("A section must be created for the selected language.  Please enter the section name and URL name.", "Tem de existir uma secção para o idioma selecionado. Introduza o nome da secção e respectivo nome URL.");
regGS("Article Type", "Tipo de artigo");
regGS("$1 articles found", "exist(m) $1 artigo(s).");
regGS("Show article on front page", "Mostrar Artigo na 1ª Página");
regGS("Show article on section page", "Mostrar Artigo na página de Secção");
regGS("Translate article", "Traduzir Artigo");
regGS("You do not have the right to change this article.  You may only edit your own articles and once submitted an article can only be changed by authorized users.", "Não tem permissões para alterar o Estado do Artigo. Apenas pode alterar os seus artigos, mas após um artigo ser submetido apenas poderá ser alterado por Utilizadores autorizados pelo Sistema.");
regGS("Edit article", "Editar Detalhes do Artigo");
regGS("Allow users without subscriptions to view the article", "Permitir que leitores sem assinatura vejam Artigo.");
regGS("The article has been locked by $1 ($2) $3 hour(s) and $4 minute(s) ago.", "O artigo foi bloqueado por $1 ($2) à $3 horas e $4 minutos.");
regGS("The article has been locked by $1 ($2) $3 minute(s) ago.", "O artigo foi bloqueado por $1 ($2) à $3 minutos.");
regGS("Are you sure you want to unlock it?", "Confirme o desbloqueamento");
regGS("Article is locked", "Artigo bloqueado");
regGS("Duplicate article", "Duplicar Artigo");
regGS("The destination section is the same as the source section.", "Secção destino idêntica à de origem.");
regGS("The article is new; it is not possible to schedule it for automatic publishing.", "Este artigo é novo; não é possivél agendar publicação automática.");
regGS("No article types were defined. You must create an article type first.", "Não existem tipos de artigos definidos. Tem de criar tipo de artigo antes.");
regGS("Edit article types", "Editar tipos de artigos");
regGS("Could not save the article. It has been locked by $1 $2 hours and $3 minutes ago.", "Não é possivél gravar artigo. Este foi bloqueado por $1 à $2 horas e $3 minutos.");
regGS("You do not have the right to change this article status. Once submitted an article can only be changed by authorized users.", "Não tem permissões para alterar o estado do artigo. Uma vez submetido apenas os utilizadores autorizados podem alterar o seu estado.");
regGS("You do not have the right to delete articles.", "Não tem permissões para eliminar artigos. ");
regGS("You must select an article type.", "Tem de escolher o tipo de artigo.");
regGS("Are you sure you want to remove the image \'$1\' from the article?", "Confirma a eliminação da imagem \'$1\' do artigo?");
regGS("Are you sure you want to delete this scheduled action?", "");
regGS("Are you sure you want to remove the topic \\'$1\\' from the article?", "Confirma a eliminação do tópico \\'$1\\' do artigo?");
regGS("Are you sure you want to remove the file \\'$1\\' from the article?", "Confirma a eliminação do anexo \\'$1\\' do artigo?");
regGS("Are you sure you want to remove the image \\'$1\\' from the article?", "Confirma a eliminação da imagem \\'$1\\' do artigo?");
?>
